# -*- coding: utf-8 -*-
"""A bishop chess piece."""

from .figure import Figure


class Bishop(Figure):

    """A bishop chess piece."""

    start_position = {"white": ("C1", "F1"),
                      "black": ("C8", "F8")}

    def __str__(self):
        if self.color == "white":
            string = "♗"
        else:
            string = "♝"
        return string

    @property
    def legal_moves(self):
        """Return legal moves from current position."""
        return self._fields_in_directions(("above_right", "below_right",
                                           "above_left", "below_left"))



# -*- coding: utf-8 -*-
"""Rook chess piece."""

from .figure import Figure


class Rook(Figure):

    """Rook chess piece."""

    start_position = {"white": ["A1", "H1"],
                      "black": ["A8", "H8"]}

    def __init__(self, player):
        super(Rook, self).__init__(player)

    def __str__(self):
        if self.color == "white":
            string = "♖"
        else:
            string = "♜"
        return string

    @property
    def legal_moves(self):
        """Return legal moves from current position."""
        return self._fields_in_directions(("to_left", "to_right", "above",
                                           "below"))



"""Errors for chess game"""


class ChessError(Exception):
    """An error related to chess."""


class IllegalMoveError(ChessError):
    """Proposed move is illegal."""


class IllegalCaptureError(ChessError):
    """Proposed capture is illegal."""


class TurnError(ChessError):
    """Player tried to play out of order."""


class FieldOccupiedError(ChessError):
    """Goal field is occupied."""


class FieldMustBeCastledError(ChessError):
    """King is being moved and the field is only available for castling."""


class PawnMustCaptureError(ChessError):
    """A Pawn has to capture when moving diagonally."""



#!/usr/bin/env python

from distutils.core import setup

setup(name='KingSnake',
      version='1.1.0',
      description='A Python chess game for two human players',
      author='Daniel Lee',
      author_email='Lee.Daniel.1986@gmail.com',
      url='https://github.com/erget/KingSnake',
      packages=['king_snake', 'king_snake.figures'],
      license="LICENSE",
      long_description=open("README").read(),
      scripts=["bin/kingsnake", "bin/KingSnake.py"]
     )



# -*- coding: utf-8 -*-

"""A knight chess piece."""

from .figure import Figure


class Knight(Figure):

    """A knight chess piece."""

    start_position = {"white": ("B1", "G1"),
                      "black": ("B8", "G8")}

    def __str__(self):
        if self.color == "white":
            string = "♘"
        else:
            string = "♞"
        return string

    @property
    def legal_moves(self):
        """Return legal moves from current position."""
        moves = []
        steps = {"above": ("above_left", "above_right"),
                 "below": ("below_left", "below_right"),
                 "to_left": ("above_left", "below_left"),
                 "to_right": ("above_right", "below_right")}
        for first_step in steps.keys():
            for second_step in steps[first_step]:
                first_pos = getattr(self.position, first_step)()
                if first_pos:
                    second_pos = getattr(first_pos, second_step)()
                    if second_pos:
                        moves.append(second_pos)
        return moves
